extensions [table]

globals [
          PCDoctor
          SCDoctor
          masterDiseaseList ;; master list of each disease type 
          
          alpha-chronic ;; base risks for each disease - same for all patients
          alpha-acute
          alpha-relapse
          
          chronic-weight-nmf ;; weights for the non-modifiable/modifiable risk factors for non-acute diseases 
          chronic-weight-mf
          
          acute-weight-nmf
          acute-weight-mf  
          
          max_behavior_change 
           
          rseed
        ]

breed [patients patient]
breed [diseases disease]
breed [doctors doctor]

patients-own [ 
               individualHealth
               
               probGetDisease ;; list of probability of getting each of the three types of diseases: acute, acute life-changing, chronic
               disease-mf ;; modifiable risk factor score for each patient
               alc-nmf ;; non-modifiable risk factor scores for each patient for each disease
               chronic-nmf 
               mental-nmf 
               acute-nmf
               
               disease-mf-init ;; initial health behavior; needed for behavior change with PC
               
               diseaseList ;; list indicating how many of each type of disease you have
                              
               diseaseAgentList ;; this is a list of specific diseases that each patient has (it's a list of agents)
               
               healthThreshold 
               healthThresholdPerc
               healthThresholdPerc-init
               
               amSick ;; true if either you have an acute disease or your chronic diseases have relapsed
               needsCare
               hasAppt
               patient-in-treatment?
               
               theDoctor ;;specific doctor patient has chosen for care
               
               pickedSCdoc?
               picked-doctor? 
               
               numSCVisits
               numPCVisits
               totDocVisits
               sickVisits ;; number of visits where patient had reached their health threshold 
               sickVisit? ;; boolean - true if the patient is visiting b/c their health is below threshold      
               totDzVisits
               numReferrals   
                             
               neighborhood ;; number (1 - 4) indicating which corner of the screen patient lives in     
               
               healthColor         
               
               behaviorColor
                             
               numAcuteDiseases
               
               timeSinceLastPCVisit
               
               diseasesPerVisit
               diseasesPerVisit_avg
             ]

diseases-own [ 
               sd ;; slope down
               td ;; time down
               su ;; slope up
               tu ;; time up
               timeSinceContraction
               totHealthLoss ;;residual health loss due to this disease that can be regained
               curHealthLoss ;;current amount of health lost due to the current onset/relapse of a disease
               
               timeContracted ;; tick number when disease was contracted 
               
               diseaseType ;; string indicating what type of disease it is
               
               in-decline?
               in-treatment?
               timeSinceTreatmentStart
               
               probRelapse
               numRelapses
               
                            
             ]

doctors-own [ 
              apptBook
              totEffectiveness
            ]

to setup
  clear-all
  set rseed 80
  random-seed rseed
  setup-patient-network
  setup-diseases
  setup-doctors
  setup-globals
  reset-ticks
end

;-----------------------------------------------------------------------------------------------------------------------
; setup-patient-network
;-----------------------------------------------------------------------------------------------------------------------

to setup-patient-network

  let iter1 0
  
  ; setup grid
  
  while [iter1 <= 56] 
  [
    if iter1 != 28
    [ 
      let iter2 -1
      while [iter2 <= 35] [
                             if iter2 != 17 [create-patients 1 [setxy 1 *  (iter1 - 28) 1.5 * (iter2 - 17)] ]
                             set iter2 (iter2 + 1)
                          ]
    ]
      set iter1 (iter1 + 1)
  ]

 
 ask patients with [xcor > 0 and ycor > 0 ][  
                                               set neighborhood "A"
                                               set pickedSCDoc? true
                                            ]
 
 ask patients with [xcor < 0 and ycor > 0 ][ 
                                              set neighborhood "A"
                                              set pickedSCDoc? false
                                            ]

 ask patients with [xcor > 0 and ycor < 0][ 
                                             set neighborhood "B"
                                             set pickedSCDoc? true
                                           ]
 
 ask patients with [xcor < 0 and ycor < 0][ 
                                             set neighborhood "B"
                                             set pickedSCDoc? false
                                          ]
 
  
 ask patients [
                set color white
                set heading 0
                set shape "person"
                set size 1.3
                set diseaseList [0 0 0 0] 
                set diseaseAgentList []
                 
                set individualHealth 1

                set needsCare false
                set hasAppt false
                set amSick false
                set patient-in-treatment? false
                
                set picked-doctor? false
                
                
                
                set timeSinceLastPCVisit 0
                
                set diseasesPerVisit []
              ]
 
 ; random-seed rseed
   
  ask patients with [neighborhood = "A" and pickedSCDoc?] [ 
                                                             set healthThresholdPerc Care_Threshold_A
                                                             set healthThresholdPerc-init healthThresholdPerc
                                                             set healthThreshold healthThresholdPerc * individualHealth
                                                             set probGetDisease generate-disease-probabilities
                                                          ]
  
 ; random-seed rseed
 
  ask patients with [neighborhood = "A" and not pickedSCDoc? ] [ 
                                                                  set healthThresholdPerc Care_Threshold_A
                                                                  set healthThresholdPerc-init healthThresholdPerc
                                                                  set healthThreshold healthThresholdPerc * individualHealth
                                                                  set probGetDisease generate-disease-probabilities
                                                               ]
 
 ; random-seed rseed
  
  ask patients with [neighborhood = "B" and pickedSCDoc? ] [ 
                                                              set healthThresholdPerc Care_Threshold_B
                                                              set healthThresholdPerc-init healthThresholdPerc
                                                              set healthThreshold healthThresholdPerc * individualHealth
                                                              set probGetDisease generate-disease-probabilities
                                                           ]
 ; random-seed rseed
 
  ask patients with [neighborhood = "B" and not pickedSCDoc? ] [ 
                                                                  set healthThresholdPerc Care_Threshold_B
                                                                  set healthThresholdPerc-init healthThresholdPerc
                                                                  set healthThreshold healthThresholdPerc * individualHealth
                                                                  set probGetDisease generate-disease-probabilities
                                                               ]
 


 ask patch -8 29 [
                   set plabel "Primary Care"
                   set plabel-color red
                 ]
 
 
 ask patch 20 29 [
                   set plabel "Episodic Care"
                   set plabel-color blue
                 ]
 
 ask patch -30 15 [
                     set plabel "A"
                     set plabel-color green
                   ]
 
  ask patch -30 -15 [
                     set plabel "B"
                     set plabel-color magenta
                   ]


end


;---------------------------------------------------------------------------------------------------
; setup-diseases
;---------------------------------------------------------------------------------------------------

to setup-diseases
  
  let dis nobody
  create-diseases 1 [ ht 
                      set dis self
                      set diseaseType "A"
                      set sd 0.04
                      set su 0.04
                      set td 4
                      set tu 4
                      
                      set totHealthLoss 0
                      set timeSinceContraction 0
                      
                      set in-decline? true
                      set in-treatment? false 
                      
                      ]
  
  set masterDiseaseList (list dis) 
  
  create-diseases 1 [ ht 
                      set dis self
                      set diseaseType "ALC"
                      set sd 0.7
                      set td 104
                      set su 0
                      set tu 8 ;; treatment time
                      
                      set totHealthLoss 0
                      set curHealthLoss 0
                      set timeSinceContraction 0
                      
                      set in-decline? true
                      set in-treatment? false
                      
                      set timeSinceTreatmentStart 0

                      set probRelapse 0
                     ]
  
  set masterDiseaseList lput dis masterDiseaseList
  
  create-diseases 1 [ ht 
                      set dis self
                      set diseaseType "C"
                      set sd 0.007
                      set td 100
                      set su 0
                      set tu 8 ;; treatment time
                      
                      set totHealthLoss 0
                      set curHealthLoss 0
                      set timeSinceContraction 0
                      
                      set in-decline? true
                      set in-treatment? false
                      
                      set timeSinceTreatmentStart 0
                      
                      set probRelapse 0
                     ]
  
  set masterDiseaseList lput dis masterDiseaseList
  
  create-diseases 1 [ ht 
                      set dis self
                      set diseaseType "D"
                      set sd 0.007
                      set td 100
                      set su 0
                      set tu 16 ;; treatment time
                      
                      set totHealthLoss 0
                      set curHealthLoss 0
                      set timeSinceContraction 0
                      
                      set in-decline? true
                      set in-treatment? false
                      
                      set timeSinceTreatmentStart 0
                      
                      set probRelapse 0
                    ]
  
  set masterDiseaseList lput dis masterDiseaseList
end

;-------------------------------------------------------------------------------------------------------------------
; setup-doctors
;-------------------------------------------------------------------------------------------------------------------

to setup-doctors
  let doc nobody
  create-doctors 1 [ ht
                     set doc self
                     set apptBook table:make
                     set totEffectiveness SCdoc_effectiveness ;; effort is percentage of potential health gain, which is 90% of total health loss
                   ]
  set SCDoctor doc
  
  create-doctors 1 [ ht
                     set doc self
                     set apptBook table:make
                     set totEffectiveness PCdoc_effectiveness ;; effort is percentage of potential health gain, which is 90% of total health loss
                   ]
  set PCDoctor doc
end


;---------------------------------------------------------------------------------------------------------------------------
; Go!
;--------------------------------------------------------------------------------------------------------------------------

to go
  ask patients [
                  contract-new-disease
                  check-for-relapse 
                  change-health
                  if amSick and not patient-in-treatment? and individualHealth < healthThreshold [set needsCare true] 
               ]
               
  
  ask patients with [ needsCare and not hasAppt ] [ 
                                                     let patient self
                                                     pick-doctor
                                                     ask theDoctor [ makeAnAppt patient ] 
                                                  ] 
  
  ask SCDoctor [ treatPatientsSC ]
  ask PCDoctor [ treatPatientsPC ]
  
  ask patients [update-disease-probabilities]
  
  ask patients [  
                  set patient-in-treatment? false
                  set amSick false
                  foreach diseaseAgentList [ if [in-treatment?] of ? [ set patient-in-treatment? true ] ;; this keeps patients from going to the doctor again if they
                                                                                                       ;; are currently in treatment for another disease 
                                             if [in-decline?] of ? [set amSick true] 
                                           ] 
                ]
  

  
 if freq_PC_Visits != 0 [ 
                           ask patients  with [picked-doctor? and not pickedSCDoc?] [ 
                                                                                       set timeSinceLastPCVisit (timeSinceLastPCVisit + 1)
                                                                                        if timeSinceLastPCVisit = (1 / freq_PC_Visits) * 52 
                                                                                        [ 
                                                                                          let patient self
                                                                                          ask PCDoctor [makeAnAppt patient] 
                                                                                        ] ;;have relationship-based people make regular appointmments
                                                                                     ]
                        ]
  
  ask patients with [not patient-in-treatment? and not amSick] [update-health-threshold] ;; have all patients recalculate their threshold if they're not sick or in treatment for a disease 
                                                                                          ;; (i.e. if their health is not changing)
                                                                                          
  ask patients [set totDocVisits (numPCVisits + numSCVisits)]
  
;  if any? patients with [individualHealth < 0] [ stop] ;; make sure no one's health goes negative
  
  
  
  tick
  
  if ticks >= 2500 [ stop ]
  
  plot-results
  
end


;--------------------------------------------------------------------------------------------------------------------------
; contract-new-disease
;--------------------------------------------------------------------------------------------------------------------------

to contract-new-disease
  let patient self
  foreach masterDiseaseList [ 
                              let currentDisease ?
                              let disPos position currentDisease masterDiseaseList
                              let pGetDis item disPos probGetDisease
                             
                              
                              if random-float 1 < pGetDis 
                                     [ 
                                          set diseaseList replace-item disPos diseaseList (item disPos diseaseList + 1)
                                          
                                          ;; hatch a new disease and add it to the patient's list of diseases
                                          let childDisease nobody
                                          ask currentDisease [ 
                                                                hatch 1  [ ht
                                                                           set childDisease self]
                                                             ]
                                          
                                          set diseaseAgentList lput childDisease diseaseAgentList     
                                          set amSick true

                                          if [diseaseType] of childDisease = "A" [set numAcuteDiseases (numAcuteDiseases + 1)]
                                          if [diseaseType] of childDisease = "ALC" [set patient-in-treatment? false] ;; ensures that patients automatically go to doc after ALC onset 
  
                                           ask childDisease [set timeContracted ticks]
                                     ]
                                      
                             ]

end


;-------------------------------------------------------------------------------------------------------------------
; check-for-relapse
;-------------------------------------------------------------------------------------------------------------------

to check-for-relapse
  let patient self
  foreach diseaseAgentList [ let currentDisease ?
                              if [diseaseType] of currentDisease != "A" 
                                [ ask currentDisease [if not in-treatment? and not in-decline? and random-float 1 < probRelapse
                                                        [
                                                           set in-decline? true
                                                           set timeSinceContraction 0
                                                           set numRelapses (numRelapses + 1)
                                                           ask patient [set amSick true]
                                                           if diseaseType = "ALC" [set sd 0.7
                                                                                   ask patient [ set patient-in-treatment? false]]
                                                         ]
                                                      ]
                                ]
                            ]
end

;--------------------------------------------------------------------------------------------------------------------
; change-health
;--------------------------------------------------------------------------------------------------------------------

to change-health
  foreach diseaseAgentList [ let currentDisease ?
                              ifelse [diseaseType] of currentDisease = "A" 
                               [change-health-dis-A currentDisease]
                               [change-health-dis-C currentDisease]
                            ]
      
  ifelse picked-doctor? [ ifelse pickedSCdoc? [ set healthColor 104 + ((1 - individualHealth) * 5.9) ]
                                              [ set healthColor 14 + ((1 - individualHealth) * 5.9) ] 
                        ]
                        [ 
                          set healthColor white
                        ]
  
    
   set color healthColor
end

;----------------------------------------------------------------------------------------------------------------
; change-health-dis-a
;-------------------------------------------------------------------------------------------------------------------

to change-health-dis-A [currentDisease]
  
  let patient self
  
  ;; to change health for an acute disease
  
  ifelse [timeSinceContraction] of currentDisease < [td] of currentDisease
   ;;if disease is still in the time down phase
   [  
       let healthLoss [sd] of currentDisease
       if individualHealth - [sd] of currentDisease <= 0 [set healthLoss (individualHealth)]
       
       set individualHealth (individualHealth - healthLoss)
       ask currentDisease [ 
                             set totHealthLoss (totHealthLoss + healthLoss)
                             set timeSinceContraction (timeSinceContraction + 1)
                           ] 
   ]

   [
        ;; if disease is in time-up phase
         ifelse [timeSinceContraction] of currentDisease < ([td] of currentDisease + [tu] of currentDisease)
         [
            let healthGain [su] of currentDisease
            if [totHealthLoss] of currentDisease < healthGain [set healthGain [totHealthLoss] of currentDisease]
            
            set individualHealth (individualHealth + healthGain)
            ask currentDisease [
                                 set totHealthLoss (totHealthLoss - healthGain) 
                                 set timeSinceContraction (timeSinceContraction + 1) 
                               ]
         ]
         [ 
           remove-disease currentDisease patient
         ] 
     ]

end

;------------------------------------------------------------------------------------------------------------------
; change-health-dis-c
;------------------------------------------------------------------------------------------------------------------

to change-health-dis-C [currentDisease]
  
  ifelse [in-decline?] of currentDisease 
  [
    if [timeSinceContraction] of currentDisease < [td] of currentDisease
     ;;if disease is still in the time down phase
     [  
       let healthLoss [sd] of currentDisease
       if individualHealth - [sd] of currentDisease <= 0 [set healthLoss (individualHealth)]
       
       
       set individualHealth (individualHealth - healthLoss)
       ask currentDisease [ 
                            set curHealthLoss (curHealthLoss + healthLoss)
                            set timeSinceContraction (timeSinceContraction + 1)
                          ]
       
       if [diseaseType] of currentDisease = "ALC" and [timeSinceContraction] of currentDisease = 1 [ ask currentDisease [set sd 0] ] 
     ]

  ]
  [
     ifelse [timeSinceTreatmentStart] of currentDisease < [tu] of currentDisease
     [
       let healthGain [su] of currentDisease
       set individualHealth (individualHealth + healthGain)
       ask currentDisease [ 
                            set curHealthLoss (curHealthLoss - healthGain)
                            set timeSinceTreatmentStart (timeSinceTreatmentStart + 1)
                          ]
      
    ] 
     
    [ 
      ask currentDisease [ set in-treatment? false 
                           set curHealthLoss 0  ]
     
    ]
  ]
  
end

;-------------------------------------------------------------------------------------------------------
; remove-disease
;-------------------------------------------------------------------------------------------------------

to remove-disease [currentDisease patient]
  ask patient [ 
                 let disPos position currentDisease diseaseAgentList
                 set diseaseList replace-item 0 diseaseList (item 0 diseaseList - 1) ;; only remove acute diseases, so subtract 1 from the acute slot in the disease list
                 set diseaseAgentList remove-item disPos diseaseAgentList 
               ]
  ask currentDisease [die]
  
end

;------------------------------------------------------------------------------------------------------------
; pick-doctor
;------------------------------------------------------------------------------------------------------------

to pick-doctor
  
  set picked-doctor? true
  
  let switch false
  
  foreach diseaseAgentList [ if [diseaseType] of ? = "ALC" and [in-decline?] of ? [ 
                                                                                    set theDoctor SCDoctor
                                                                                    set switch true
                                                                                  ] 
                           ]

  if not switch [ 
                   ifelse pickedSCDoc? [ set theDoctor SCDoctor ]
                                       [ set theDoctor PCDoctor ] 
                ]
  
  set sickVisit? true


                      
end

;------------------------------------------------------------------------------------------------------------
; makeAnAppt
;-------------------------------------------------------------------------------------------------------------

to makeAnAppt [patient]
    
  let apptDay ticks + 1
  
  ifelse table:has-key? apptBook apptDay
  [
    let daysList table:get apptBook apptDay
    set daysList lput patient daysList           
    table:put apptBook apptDay daysList
  ]
  
  [table:put apptBook apptDay (list patient)]
  
  ask patient [set hasAppt true]
  
end


;----------------------------------------------------------------------------------------------------------------
; treatPatients
;----------------------------------------------------------------------------------------------------------------

to treatPatientsSC
   let today ticks
  
  if table:has-key? apptBook today [
                                      let daysList table:get apptBook today
                                       foreach daysList [ask ? [seekCareSC]]
                                   ]
end

to treatPatientsPC
   let today ticks
  
  if table:has-key? apptBook today [
                                      let daysList table:get apptBook today
                                       foreach daysList [ask ? [seekCarePC]]
                                   ]
end

;----------------------------------------------------------------------------------------------------------------------
; seekCare
;----------------------------------------------------------------------------------------------------------------------

to seekCareSC
   let switch false
   
   ;; check if this is a sick visit
   if sickVisit? [
                   set sickVisits (sickVisits + 1)
                   set sickVisit? false
                 ] 

   
   
   ; Treat active acute life-threatening diseases first
  foreach diseaseAgentList [ 
                               let currentDisease ?
                               if [diseaseType] of currentDisease = "ALC" and [in-decline?] of currentDisease 
                               [ 
                                   set switch true
                                   ask currentDisease [ 
                                                        set timeSinceTreatmentStart 0 
                                                        set su (SCdoc_effectiveness * curHealthLoss  / tu ) 
                                                        set in-decline? false
                                                        set in-treatment? true
                                                      ] 
                                ]
                            ]
  
  ; Treat acute diseases next
   if not switch [ 
     
                   foreach diseaseAgentList [ 
                                                let currentDisease ?
                                                if [diseaseType] of currentDisease = "A" 
                                                [ 
                                                    set switch true
                                                    ask currentDisease [ 
                                                                         set timeSinceContraction td
                                                                         set su (totHealthLoss / tu) 
                                                                         set in-decline? false
                                                                         set in-treatment? true
                                                                       ]
                                                ]
                                            ] 
               ]
 
 ;; Treat remaining health concerns
 if not switch [

  
  let diseasesToCheck diseaseAgentList

  if not empty? diseasesToCheck [                    
                   
   
    
                  let max-healthLoss 0
                  let max-position 0

                       foreach diseasesToCheck [  
                                                  if ([totHealthLoss] of ? + [curHealthLoss] of ?) > max-healthLoss
                                                   [ 
                                                        set max-healthLoss ([totHealthLoss] of ? + [curHealthLoss] of ?)
                                                        set max-position position ? diseasesToCheck  
                                                    ]               
                                               ]
                   
                   let currentDisease item max-position diseasesToCheck
                   
                   
                   ; Compute effectiveness, apply to the disease that has caused the most health loss
                   

                   ask currentDisease [ 
                                           set timeSinceTreatmentStart 0   
                                           set su (( SCdoc_effectiveness * curHealthLoss) / tu)
                                           set in-decline? false
                                           set in-treatment? true  
                                     ] 
                   
                   
                     
                ]
 ]
  
  
  set numSCVisits (numSCVisits + 1)                             
  set needsCare false
  set hasAppt false
  
  
end

;-----------------------------------------------------------------------------------------------------------------------------
; seekCarePC
;-----------------------------------------------------------------------------------------------------------------------------

to seekCarePC

  let switch false
   
   ;; check if this is a sick visit
   if sickVisit? [ 
                   set sickVisits (sickVisits + 1)
                   set sickVisit? false
                 ]
   
   
  ;; Treat active acute life-threatening diseases first - this is in the PC part of the code in case a patient has an ALC event on the same tick as an appointment
  foreach diseaseAgentList [ 
                               let currentDisease ?
                               if [diseaseType] of currentDisease = "ALC" and [in-decline?] of currentDisease 
                               [ 
                                   set switch true
                                   ask currentDisease [ 
                                                        set timeSinceTreatmentStart 0 
                                                        set su (SCdoc_effectiveness * curHealthLoss  / tu ) 
                                                        set in-decline? false
                                                        set in-treatment? true
                                                      ] 
                                ]
                            ]
  
  ;; Treat everything else
  if not switch [

  let diseasesToCheck diseaseAgentList   

  if not empty? diseasesToCheck and amSick [
                                                 let max-healthLoss 0
                                                 let max-position 0
                                                 let thl 0

                                                 foreach diseasesToCheck 
                                                 [  
                                                     if [diseaseType] of ? != "ALC" and [diseaseType] of ? != "A"
                                                     [
                                                         if [curHealthLoss] of ? > max-healthLoss
                                                         [ 
                                                            set max-healthLoss ([curHealthLoss] of ?)
                                                            set max-position position ? diseasesToCheck  
                                                         ]
                                                         
                                                         set thl (thl + [curHealthLoss] of ?) 
                                                            
                                                     ]
                                                      
                                                                    
                                                 ]
                                                 
                                                if thl > 0 [set totDzVisits (totDzVisits + 1) ] ;; if total health loss > 0, then there is some health be gained, meaning some dz needs treatment. 
                                                
                                                let PCgain PCDoc_effectiveness * thl
                                                let SCgain SCDoc_effectiveness * max-healthLoss
                                                
                                                let rExp 0
                                                
                                                if referExp <= 4 [set rExp referExp]
                                                if referExp = 5 [set rExp 6]
                                                if referExp = 6 [set rExp 8]
                                                if referExp = 7 [set rExp 10]
                                                if referExp = 8 [set rExp 15]
                                                if referExp = 9 [set rExp 20]
                                                if referExp = 10 [set rExp 30]
                           
                                                let probRefer 0
                                                if SCgain > 0 [ set probRefer 1 - (PCgain / SCgain) ^ (rExp) ]
                                                
                                                
                                                ifelse random-float 1 < probRefer
                                                [ 
                                                   let currentDisease item max-position diseasesToCheck
                                                  
                                                   ask currentDisease [ 
                                                                        set timeSinceTreatmentStart 0   
                                                                        set su (( SCdoc_effectiveness * curHealthLoss) / tu)
                                                                        set in-decline? false
                                                                        set in-treatment? true  
                                                                     ]   
                                                   
                                                   set numReferrals (numReferrals + 1)
                                                   set numSCVisits (numSCVisits + 1)
                                                  
                                                ]
                                                [
                                                
                                                     foreach diseasesToCheck 
                                                     [ 
                                                         let currentDisease ?
                                                         ifelse [diseaseType] of currentDisease = "A"
                                                         [
                                                            ask currentDisease [ 
                                                                                  set timeSinceContraction td
                                                                                  set su (totHealthLoss / tu) 
                                                                                  set in-decline? false
                                                                                  set in-treatment? true
                                                                               ]
                                                         ]  
                                                         [
                                                             ask currentDisease [ 
                                                                                   if not in-treatment? and totHealthLoss + curHealthLoss > 0
                                                                                   [ 
                                                                                       set timeSinceTreatmentStart 0 
                                                                                      
                                                                                       set su ((PCdoc_effectiveness * curHealthLoss) / tu) 
                                                                                    
                                                                                       set in-decline? false
                                                                                       set in-treatment? true
                                                                                    ]
                                                                                 ]   
                                                         ]                                                                                
                                                      ]
                                                ]
                                                
                                                       
                                         ]
  
      ; change health behavior
    
    let behavior_change_rate 0.35
    
   
    ifelse disease-mf-init - max_behavior_change > 0.15
    [ set disease-mf (max_behavior_change * 1 / (1 + 0.01 * exp(behavior_change_rate * numPCVisits)) + (disease-mf-init - max_behavior_change)) ]
    [ set disease-mf ((disease-mf-init - 0.15) * 1 / (1 + 0.01 * exp(behavior_change_rate * numPCVisits)) + 0.15) ]
     
     
    
    let threshold_change_rate -1
    
    ifelse healthThresholdPerc-init + max_threshold_change < 0.85
   [ set healthThresholdPerc (max_threshold_change * 1 / (1 + 100 * exp(threshold_change_rate * numPCVisits)) + healthThresholdPerc-init) ]
   [ set healthThresholdPerc ( (0.85 - healthThresholdPerc-init) * 1 / (1 + 100 * exp(threshold_change_rate * numPCVisits)) + healthThresholdPerc-init) ]
   

  
  ]
  

  set timeSinceLastPCVisit 0
  set numPCVisits (numPCVisits + 1)                             
  set needsCare false
  set hasAppt false
  
end


;----------------------------------------------------------------------------------------------------------------------------
; update-health-threshold
;----------------------------------------------------------------------------------------------------------------------------

to update-health-threshold
  
  ifelse healthThresholdPerc * individualHealth > 0.05 [ set healthThreshold (healthThresholdPerc * individualHealth) ]
                                                       [ set healthThreshold 0.05]

end

;-----------------------------------------------------------------------------------------------------------------------
; check-for-provider-switch
;-----------------------------------------------------------------------------------------------------------------------

to check-for-provider-switch
  
  let provider-change-rate -60
  
  let totDiseases (item 1 diseaseList + item 2 diseaseList + item 3 diseaseList)
  
  ifelse pickedSCDoc?
  [ 
    
    if any? patients with [not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList = totDiseases ]
    [
       let avgCounterpartHealth (mean [individualHealth] of patients with [not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList = totDiseases ]) 
       if individualHealth < avgCounterpartHealth
       [
           if random-float 1 < 1 / (1 + 200 * exp(provider-change-rate * (avgCounterpartHealth - individualHealth)))
           [
              set pickedSCDoc? false
           ] 
       ]
    ]
    
  ]
  [ 
    
    if any? patients with [pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList = totDiseases ]
    [
        let avgCounterpartHealth (mean [individualHealth] of patients with [pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList = totDiseases ]) 
        if individualHealth < avgCounterpartHealth
        [
              if random-float 1 < 1 / (1 + 200 * exp(provider-change-rate * (avgCounterpartHealth - individualHealth)))
              [
                 set pickedSCDoc? true
              ] 
         ]
    ]
    
  ]
end

;----------------------------------------------------------------------------------------------------------------------------
; generate-disease-probabilities
;----------------------------------------------------------------------------------------------------------------------------

to-report generate-disease-probabilities
  set alpha-chronic -9.9034
  set alpha-acute -4.17
  set alpha-relapse -7.75
  
  set chronic-weight-nmf 1.5
  set chronic-weight-mf 1.5
  
  set acute-weight-nmf 0.35
  set acute-weight-mf 0.35
  
  ifelse neighborhood = "A" [ set disease-mf 0.15 + (Health_Behavior_A - 1) * 0.175 ] 
                            [ set disease-mf 0.15 + (Health_Behavior_B - 1) * 0.175 ]
  
  set disease-mf-init disease-mf
  
  set chronic-nmf get-tri-rand 0 1 0.5
  set alc-nmf get-tri-rand 0 1 0.5
  set mental-nmf get-tri-rand 0 1 0.5
  
  set acute-nmf get-tri-rand 0 1 0.5
  
  let acute-prob 1 / (1 + exp(-(alpha-acute + acute-weight-nmf * acute-nmf + acute-weight-mf * disease-mf)))
  let alc-prob 1 / (1 + exp(-(alpha-chronic + chronic-weight-nmf * alc-nmf + chronic-weight-mf * disease-mf)))
  let chronic-prob 1 / (1 + exp(-(alpha-chronic + chronic-weight-nmf * chronic-nmf + chronic-weight-mf * disease-mf)))
  let mental-prob 1 / (1 + exp(-(alpha-chronic + chronic-weight-nmf * mental-nmf + chronic-weight-mf * disease-mf)))
  
  report (list acute-prob alc-prob chronic-prob mental-prob)
end

;-------------------------------------------------------------------------------------------------------------------------------
; update-disease-probabilities: changes probability of either contracting a new disease or relapsing after a behavior change
;-------------------------------------------------------------------------------------------------------------------------------

to update-disease-probabilities
  let patient self
  
  ; change patient's probability of contracting a new disease
  let acute-prob 1 / (1 + exp(-(alpha-acute + acute-weight-nmf * acute-nmf + acute-weight-mf * disease-mf)))
  let alc-prob 1 / (1 + exp(-(alpha-chronic + chronic-weight-nmf * alc-nmf + chronic-weight-mf * disease-mf)))
  let chronic-prob 1 / (1 + exp(-(alpha-chronic + chronic-weight-nmf * chronic-nmf + chronic-weight-mf * disease-mf)))
  let mental-prob 1 / (1 + exp(-(alpha-chronic + chronic-weight-nmf * mental-nmf + chronic-weight-mf * disease-mf)))
  
  set probGetDisease (list acute-prob alc-prob chronic-prob mental-prob)
  
  ; change each disease's probability of relapsing
  foreach diseaseAgentList [ 
                              if [diseaseType] of ? = "ALC" [ ask ? [set probRelapse (1 / (1 + exp(-(alpha-relapse + chronic-weight-nmf * [alc-nmf] of patient + chronic-weight-mf * [disease-mf] of patient)))) ]]
    
                              if [diseaseType] of ? = "C" [ ask ? [set probRelapse (1 / (1 + exp(-(alpha-relapse + chronic-weight-nmf * [chronic-nmf] of patient + chronic-weight-mf * [disease-mf] of patient)))) ]]
                                          
                              if [diseaseType] of ? = "D" [ ask ? [set probRelapse (1 / (1 + exp(-(alpha-relapse + chronic-weight-nmf * [mental-nmf] of patient + chronic-weight-mf * [disease-mf] of patient)))) ]]
                           ]
end


;------------------------------------------------------------------------------------------------------------------------------
; setup-globals
;------------------------------------------------------------------------------------------------------------------------------

to setup-globals
  
  set max_behavior_change 0.175 * Category_Change
end



;--------------------------------------------------------------------------------------------------------------
; plot-results
;--------------------------------------------------------------------------------------------------------------

to plot-results

  set-current-plot "Referrals vs. Total PC Visits (A)"
  set-current-plot-pen "Referrals"
  set-plot-pen-mode 1 
  plotxy 1.5 mean [numReferrals] of patients with [not pickedSCDoc? and neighborhood = "A"]

   set-current-plot-pen "PC Visits"
  set-plot-pen-mode 1 
  plotxy 0.5 mean [totDzVisits] of patients with [not pickedSCDoc? and neighborhood = "A"]
  
  
  set-current-plot "Referrals vs. Total PC Visits (B)"
  set-current-plot-pen "Referrals"
  set-plot-pen-mode 1 
  plotxy 1.5 mean [numReferrals] of patients with [not pickedSCDoc? and neighborhood = "B"]

   set-current-plot-pen "PC Visits"
  set-plot-pen-mode 1 
  plotxy 0.5 mean [totDzVisits] of patients with [not pickedSCDoc? and neighborhood = "B"]
  
    set-current-plot "Health (A, >2 dz)"
  set-current-plot-pen "PC"
  if count patients with [neighborhood = "A" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] >= 50
  [ plotxy ticks mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] ]
  
  set-current-plot-pen "EC"
  if count patients with [neighborhood = "A" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] >= 50
  [ plotxy ticks mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] ]
  
  set-current-plot "Health (B, >2 dz)"
  set-current-plot-pen "PC"
  if count patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] >= 50
  [ plotxy ticks mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] ]
  
  set-current-plot-pen "EC"
  if count patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] >= 50
  [ plotxy ticks mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3] ]
  
  
end

;---------------------------------------------------------------------------------------------------------------
; get-tri-rand
;--------------------------------------------------------------------------------------------------------------

to-report get-tri-rand [ a b c ]
  let t random-float 1
  let x 0
  ifelse t <= (c - a) / (b - a)
  [set x (a + sqrt(t * (b - a) * (c - a)))  ]
  [set x (b - sqrt((1 - t) * (b - a) * (b - c)))]
  report x 
end
@#$#@#$#@
GRAPHICS-WINDOW
332
10
846
529
31
30
8.0
1
18
1
1
1
0
1
1
1
-31
31
-30
30
0
0
1
ticks
30.0

BUTTON
9
10
72
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
77
10
140
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
169
357
320
390
SCdoc_effectiveness
SCdoc_effectiveness
0
1
0.9
0.05
1
NIL
HORIZONTAL

SLIDER
8
357
160
390
PCdoc_effectiveness
PCdoc_effectiveness
0
1
0.75
0.05
1
NIL
HORIZONTAL

SLIDER
7
419
159
452
freq_PC_Visits
freq_PC_Visits
0
2
1
1
1
NIL
HORIZONTAL

SLIDER
7
482
157
515
Category_Change
Category_Change
0
4
0
1
1
NIL
HORIZONTAL

SLIDER
6
546
160
579
max_threshold_change
max_threshold_change
0
0.4
0
0.1
1
NIL
HORIZONTAL

SLIDER
9
138
140
171
Health_Behavior_A
Health_Behavior_A
1
5
3
1
1
NIL
HORIZONTAL

TEXTBOX
15
120
151
138
Good                   Bad
12
0.0
1

TEXTBOX
15
220
145
241
Low                   High
12
0.0
1

SLIDER
7
238
144
271
Care_Threshold_A
Care_Threshold_A
0.45
0.85
0.75
0.1
1
NIL
HORIZONTAL

TEXTBOX
51
317
139
336
Primary Care
14
15.0
1

TEXTBOX
13
339
163
357
Effectiveness
12
0.0
1

TEXTBOX
206
318
301
336
Episodic Care
14
105.0
1

TEXTBOX
89
78
265
99
Health Behavior Category\n
14
0.0
1

TEXTBOX
90
181
254
200
Care Seeking Tendency
14
0.0
1

TEXTBOX
9
398
159
416
Check-ups per year
12
0.0
1

TEXTBOX
8
464
158
482
Health behavior help
12
0.0
1

TEXTBOX
10
525
160
543
Earlier care seeking
12
0.0
1

TEXTBOX
174
339
324
357
Effectiveness
12
0.0
1

BUTTON
148
10
223
43
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
51
101
130
119
Group A
14
55.0
1

SLIDER
158
137
290
170
Health_Behavior_B
Health_Behavior_B
1
5
5
1
1
NIL
HORIZONTAL

TEXTBOX
164
119
296
137
Good                   Bad
12
0.0
1

TEXTBOX
204
100
265
118
Group B
14
125.0
1

TEXTBOX
49
202
109
220
Group A
14
55.0
1

SLIDER
157
238
293
271
Care_Threshold_B
Care_Threshold_B
0.45
0.85
0.45
0.1
1
NIL
HORIZONTAL

TEXTBOX
200
201
260
219
Group B
14
125.0
1

TEXTBOX
163
220
313
238
Low                    High
12
0.0
1

PLOT
859
14
1088
190
 Health (A)
NIL
NIL
0.0
2500.0
0.0
1.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" "plot mean [individualHealth] of patients with [neighborhood = \"A\" and not pickedSCDoc?]"
"EC" 1.0 0 -13345367 true "" "plot mean [individualHealth] of patients with [neighborhood = \"A\" and pickedSCDoc?]"

PLOT
1095
13
1318
188
 Health (B)
NIL
NIL
0.0
2500.0
0.0
1.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" "plot mean [individualHealth] of patients with [neighborhood = \"B\" and not pickedSCDoc?]"
"EC" 1.0 0 -13345367 true "" "plot mean [individualHealth] of patients with [neighborhood = \"B\" and pickedSCDoc?]"

TEXTBOX
66
288
282
314
Healthcare Characteristics
18
0.0
1

TEXTBOX
76
51
254
77
Patient Characteristics
18
0.0
1

MONITOR
1487
70
1557
115
Health
mean [individualHealth] of patients with [neighborhood = \"A\" and pickedSCDoc?]
4
1
11

MONITOR
1357
69
1424
114
Health 
mean [individualHealth] of patients with [neighborhood = \"A\" and not pickedSCDoc?]
4
1
11

TEXTBOX
1419
16
1519
35
Group A Results
14
55.0
1

TEXTBOX
1360
40
1448
58
Primary Care
14
15.0
1

TEXTBOX
1486
42
1590
60
Episodic Care
14
105.0
1

MONITOR
1357
120
1441
165
Health (>2 dz)
mean [individualHealth] of patients with [neighborhood = \"A\" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3]
4
1
11

MONITOR
1487
120
1572
165
Health (>2 dz)
mean [individualHealth] of patients with [neighborhood = \"A\" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3]
4
1
11

MONITOR
1357
171
1429
216
Total Visits
mean [totDocVisits] of patients with [neighborhood = \"A\" and not pickedSCDoc?]
2
1
11

MONITOR
1487
172
1552
217
Total Visits
mean [totDocVisits] of patients with [neighborhood = \"A\" and pickedSCDoc?]
2
1
11

MONITOR
1359
222
1431
267
Sick Visits
mean [sickVisits] of patients with [neighborhood = \"A\" and not pickedSCDoc?]
2
1
11

MONITOR
1488
222
1553
267
Sick Visits
mean [sickVisits] of patients with [neighborhood = \"A\" and pickedSCDoc?]
2
1
11

TEXTBOX
1687
15
1794
33
Group B Results
14
125.0
1

TEXTBOX
1620
43
1706
61
Primary Care
14
15.0
1

TEXTBOX
1750
44
1845
62
Episodic Care
14
105.0
1

MONITOR
1621
69
1694
114
Health
mean [individualHealth] of patients with [neighborhood = \"B\" and not pickedSCDoc?]
4
1
11

MONITOR
1749
70
1816
115
Health
mean [individualHealth] of patients with [neighborhood = \"B\" and pickedSCDoc?]
4
1
11

MONITOR
1621
120
1712
165
Health (>2 dz)
mean [individualHealth] of patients with [neighborhood = \"B\" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3]
4
1
11

MONITOR
1749
119
1836
164
Health (>2 dz)
mean [individualHealth] of patients with [neighborhood = \"B\" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList >= 3]
4
1
11

MONITOR
1622
169
1694
214
Total Visits
mean [totDocVisits] of patients with [neighborhood = \"B\" and not pickedSCDoc?]
2
1
11

MONITOR
1751
168
1823
213
Total Visits
mean [totDocVisits] of patients with [neighborhood = \"B\" and pickedSCDoc?]
2
1
11

MONITOR
1623
218
1695
263
Sick Visits
mean [sickVisits] of patients with [neighborhood = \"B\" and not pickedSCDoc?]
2
1
11

MONITOR
1750
218
1820
263
Sick Visits
mean [sickVisits] of patients with [neighborhood = \"B\" and pickedSCDoc?]
2
1
11

TEXTBOX
336
536
849
590
Patients remain white until they seek care for the first time. The colors of the patients correspond to their individual health, with dark red/dark blue corresponding to the best health. As a patient becomes more unhealthy, their color fades. 
14
0.0
1

SLIDER
4
606
161
639
referExp
referExp
0
10
0
1
1
NIL
HORIZONTAL

TEXTBOX
10
587
160
605
Tendency to refer
12
0.0
1

PLOT
1347
303
1608
474
Referrals vs. Total PC Visits (A)
NIL
NIL
0.0
3.0
0.0
8.0
true
true
"" ""
PENS
"PC Visits" 1.0 0 -16777216 true "" ""
"Referrals" 1.0 0 -10899396 true "" ""

PLOT
1346
483
1611
652
Referrals vs. Total PC Visits (B)
NIL
NIL
0.0
3.0
0.0
8.0
true
true
"" ""
PENS
"PC Visits" 1.0 0 -16777216 true "" ""
"Referrals" 1.0 0 -10899396 true "" ""

MONITOR
1621
303
1721
348
% Referred (A)
(mean [numReferrals] of patients with [not pickedSCDoc? and neighborhood = \"A\"] / mean [totDzVisits] of patients with [not pickedSCDoc? and neighborhood = \"A\"]) * 100
2
1
11

MONITOR
1624
487
1722
532
% Referred (B)
(mean [numReferrals] of patients with [not pickedSCDoc? and neighborhood = \"B\"] / mean [totDzVisits] of patients with [not pickedSCDoc? and neighborhood = \"B\"]) * 100
2
1
11

PLOT
859
195
1085
369
Health (A, >2 dz)
NIL
NIL
0.0
2500.0
0.0
1.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" ""
"EC" 1.0 0 -13345367 true "" ""

PLOT
1095
192
1314
369
Health (B, >2 dz)
NIL
NIL
0.0
2500.0
0.0
1.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" ""
"EC" 1.0 0 -13345367 true "" ""

PLOT
859
373
1084
551
Total Visits (A)
NIL
NIL
0.0
2500.0
0.0
80.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" "plot mean [totDocVisits] of patients with [neighborhood = \"A\" and not pickedSCDoc?]"
"EC" 1.0 0 -13345367 true "" "plot mean [totDocVisits] of patients with [neighborhood = \"A\" and pickedSCDoc?]"

PLOT
1099
374
1311
551
Total Visits (B)
NIL
NIL
0.0
2500.0
0.0
80.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" "plot mean [totDocVisits] of patients with [neighborhood = \"B\" and not pickedSCDoc?]"
"SC" 1.0 0 -13345367 true "" "plot mean [totDocVisits] of patients with [neighborhood = \"B\" and pickedSCDoc?]"

PLOT
859
554
1083
733
Sick Visits (A)
NIL
NIL
0.0
2500.0
0.0
80.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" "plot mean [sickVisits] of patients with [neighborhood = \"A\" and not pickedSCDoc?]"
"SC" 1.0 0 -13345367 true "" "plot mean [sickVisits] of patients with [neighborhood = \"A\" and pickedSCDoc?]"

PLOT
1096
555
1312
733
Sick Visits (B)
NIL
NIL
0.0
2500.0
0.0
80.0
true
true
"" ""
PENS
"PC" 1.0 0 -2674135 true "" "plot mean [sickVisits] of patients with [neighborhood = \"B\" and not pickedSCDoc?]"
"SC" 1.0 0 -13345367 true "" "plot mean [sickVisits] of patients with [neighborhood = \"B\" and pickedSCDoc?]"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="no_limit_behavior_change_5_45" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Category_Change" first="1" step="1" last="4"/>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="different_thresholds_noacutes" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <steppedValueSet variable="Care_Threshold_B" first="0.45" step="0.1" last="0.85"/>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fixed_threshold_80" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_freq_PCVisits_change" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="freq_PCVisits_change_high_threshold" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_fixed_threshold_45" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_fixed_threshold_55" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_fixed_threshold_65" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.65"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_fixed_threshold_75" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_fixed_threshold_85" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_freq_PCVisits_change_high_threshold" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_behavior_change_5_55" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Category_Change" first="1" step="1" last="4"/>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_behavior_change_5_65" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.65"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Category_Change" first="1" step="1" last="4"/>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_behavior_change_5_75" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Category_Change" first="1" step="1" last="4"/>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_behavior_change_5_85" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Category_Change" first="1" step="1" last="4"/>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_fixed_threshold_45" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Health_Behavior_B" first="1" step="1" last="5"/>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_behavior_change_1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_effectiveness_change_good_behavior" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.8"/>
      <value value="0.85"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_effectiveness_change_bad_behavior" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.8"/>
      <value value="0.85"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_effectiveness_change_bad_behavior_75" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.8"/>
      <value value="0.85"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no_limit_effectiveness_change_good_behavior_75" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.8"/>
      <value value="0.85"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="session7_experiments" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="0"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="effectiveness_threshold_tests_5" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="PCdoc_effectiveness" first="0.5" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="effectiveness_threshold_tests_4" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="PCdoc_effectiveness" first="0.5" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="effectiveness_threshold_tests_3" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="PCdoc_effectiveness" first="0.5" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="effectiveness_threshold_tests_2" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="PCdoc_effectiveness" first="0.5" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="effectiveness_threshold_tests_1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and pickedSCDoc?]</metric>
    <metric>mean [sickVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="PCdoc_effectiveness" first="0.5" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="session8_experiments" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2500"/>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [totDocVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [numReferrals] of patients with [neighborhood = "A" and not pickedSCDoc?] / mean [totDzVisits] of patients with [neighborhood = "A" and not pickedSCDoc?]</metric>
    <metric>mean [numReferrals] of patients with [neighborhood = "B" and not pickedSCDoc?] / mean [totDzVisits] of patients with [neighborhood = "B" and not pickedSCDoc?]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "A" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <metric>mean [individualHealth] of patients with [neighborhood = "B" and not pickedSCDoc? and item 1 diseaseList + item 2 diseaseList + item 3 diseaseList &gt;= 3]</metric>
    <enumeratedValueSet variable="referExp">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="freq_PC_Visits">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_B">
      <value value="0.45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PCdoc_effectiveness">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Care_Threshold_A">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Category_Change">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SCdoc_effectiveness">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_threshold_change">
      <value value="0"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Health_Behavior_B">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
